/// <reference types="node" />
import { IncomingMessage, ServerResponse } from 'http';
import { EventEmitter } from 'events';
import { Store } from 'express-session';
interface SessionOptions {
    genid?: (req?: IncomingMessage) => string;
    name?: string;
    key?: string;
    store?: Store;
    resave?: boolean;
    rolling?: boolean;
    saveUninitialized?: boolean;
    secret: string | string[];
    unset?: string;
    cookie?: Express.SessionCookieData;
}
declare class Cookie implements Express.SessionCookie {
    _expires: Date | boolean;
    originalMaxAge: number;
    secure: boolean;
    httpOnly: boolean;
    path: string;
    domain?: string;
    sameSite: boolean | 'lax' | 'strict' | 'none' | undefined;
    constructor(options?: Express.SessionCookieData);
    expires: Date | boolean;
    maxAge: number | null;
    readonly data: {
        originalMaxAge: number;
        expires: Date | undefined;
        secure: boolean;
        httpOnly: boolean;
        domain: string | undefined;
        path: string;
        sameSite: boolean | "none" | "lax" | "strict" | undefined;
    };
    serialize(name: string, val: string): string;
}
declare class SessionData implements Express.Session {
    id: string;
    req: any;
    store: Store;
    cookie: Cookie;
    [key: string]: any;
    constructor(req: any, sessionData: any);
    resetMaxAge(): this;
    touch(): this;
    save(cb?: (err?: any) => void): this;
    reload(cb?: (err?: any) => void): this;
    destroy(cb?: (err?: any) => void): this;
    regenerate(cb: (err?: any) => void): this;
}
export declare class MemoryStore extends EventEmitter implements Store {
    private sessions;
    generate?: (req: IncomingMessage) => void;
    constructor();
    regenerate(req: any, cb?: (err?: any) => void): void;
    load(id: string, cb: (err?: any, session?: SessionData) => void): void;
    createSession(req: any, session: any): SessionData;
    all(cb: (err?: any, sessions?: {
        [id: string]: any;
    }) => void): void;
    clear(cb?: (err?: any) => void): void;
    destroy(id: string, cb?: (err?: any) => void): void;
    get(id: string, cb: (err?: any, session?: any) => void): void;
    set(id: string, session: any, cb?: (err?: any) => void): void;
    length(cb: (err?: any, length?: number) => void): void;
    touch(id: string, session: any, cb?: (err?: any) => void): void;
    getSession(id: string): any;
}
export declare function Session(options: SessionOptions): (req: IncomingMessage, res: ServerResponse) => Promise<SessionData>;
export {};
